package org.dromara.zhishu.mapper;

import org.apache.ibatis.annotations.Mapper;
import org.dromara.common.mybatis.core.mapper.BaseMapperPlus;
import org.dromara.zhishu.domain.Logistics;
import org.dromara.zhishu.domain.bo.LogisticsBo;
import org.dromara.zhishu.domain.vo.LogisticsVo;

import java.util.List;

@Mapper
public interface LogisticsMapper extends BaseMapperPlus<Logistics, LogisticsVo> {


    String selectByArea(Integer deliveryArea, Integer deliveryCity);

    String selectByProvince(Integer deliveryProvince);

    String selectByCity(Integer deliveryCity, Integer deliveryProvince);

    int insert(Logistics add);

    List<Logistics> selectLogistice(String warehouseId);

    Logistics selectByWareId(Long id);

    Long selectByid(String proName,String cityName,String areaName,Long proId, Long cityId);

    Integer updateByBo(Logistics bo);
}
